==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ControlNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActivityFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ControlNode;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.DecisionMergeNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.FlowFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ForkJoinNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.InitialNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityFinalNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.DecisionMergeNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.FlowFinalNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ForkJoinNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.InitialNodeSetImpl;

import java.util.Arrays;
import java.util.List;


public class ControlNodeSetImpl extends InstanceSet<ControlNodeSet,ControlNode> implements ControlNodeSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ControlNode controlnode : this ) controlnode.setId( ref_Id );
    }


    // selections
    @Override
    public ActivityNodeSet R1105_is_a_ActivityNode() throws XtumlException {
        ActivityNodeSet activitynodeset = new ActivityNodeSetImpl();
        for ( ControlNode controlnode : this ) activitynodeset.add( controlnode.R1105_is_a_ActivityNode() );
        return activitynodeset;
    }
    @Override
    public ActivityFinalNodeSet R1106_is_a_ActivityFinalNode() throws XtumlException {
        ActivityFinalNodeSet activityfinalnodeset = new ActivityFinalNodeSetImpl();
        for ( ControlNode controlnode : this ) activityfinalnodeset.add( controlnode.R1106_is_a_ActivityFinalNode() );
        return activityfinalnodeset;
    }
    @Override
    public DecisionMergeNodeSet R1106_is_a_DecisionMergeNode() throws XtumlException {
        DecisionMergeNodeSet decisionmergenodeset = new DecisionMergeNodeSetImpl();
        for ( ControlNode controlnode : this ) decisionmergenodeset.add( controlnode.R1106_is_a_DecisionMergeNode() );
        return decisionmergenodeset;
    }
    @Override
    public FlowFinalNodeSet R1106_is_a_FlowFinalNode() throws XtumlException {
        FlowFinalNodeSet flowfinalnodeset = new FlowFinalNodeSetImpl();
        for ( ControlNode controlnode : this ) flowfinalnodeset.add( controlnode.R1106_is_a_FlowFinalNode() );
        return flowfinalnodeset;
    }
    @Override
    public ForkJoinNodeSet R1106_is_a_ForkJoinNode() throws XtumlException {
        ForkJoinNodeSet forkjoinnodeset = new ForkJoinNodeSetImpl();
        for ( ControlNode controlnode : this ) forkjoinnodeset.add( controlnode.R1106_is_a_ForkJoinNode() );
        return forkjoinnodeset;
    }
    @Override
    public InitialNodeSet R1106_is_a_InitialNode() throws XtumlException {
        InitialNodeSet initialnodeset = new InitialNodeSetImpl();
        for ( ControlNode controlnode : this ) initialnodeset.add( controlnode.R1106_is_a_InitialNode() );
        return initialnodeset;
    }


    @Override
    public ControlNode nullElement() {
        return ControlNodeImpl.EMPTY_CONTROLNODE;
    }

    @Override
    public ControlNodeSet emptySet() {
      return new ControlNodeSetImpl();
    }

    @Override
    public ControlNodeSet value() {
        return this;
    }

    @Override
    public List<ControlNode> elements() {
        return Arrays.asList(toArray(new ControlNode[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ControlNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActivityFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ControlNode;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.DecisionMergeNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.FlowFinalNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ForkJoinNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.InitialNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityFinalNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.DecisionMergeNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.FlowFinalNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ForkJoinNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.InitialNodeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ControlNodeSetImpl extends InstanceSet<ControlNodeSet,ControlNode> implements ControlNodeSet {

    public ControlNodeSetImpl() {
    }

    public ControlNodeSetImpl(Comparator<? super ControlNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ControlNode controlnode : this ) controlnode.setId( ref_Id );
    }


    // selections
    @Override
    public ActivityNodeSet R1105_is_a_ActivityNode() throws XtumlException {
        ActivityNodeSet activitynodeset = new ActivityNodeSetImpl();
        for ( ControlNode controlnode : this ) activitynodeset.add( controlnode.R1105_is_a_ActivityNode() );
        return activitynodeset;
    }
    @Override
    public ActivityFinalNodeSet R1106_is_a_ActivityFinalNode() throws XtumlException {
        ActivityFinalNodeSet activityfinalnodeset = new ActivityFinalNodeSetImpl();
        for ( ControlNode controlnode : this ) activityfinalnodeset.add( controlnode.R1106_is_a_ActivityFinalNode() );
        return activityfinalnodeset;
    }
    @Override
    public DecisionMergeNodeSet R1106_is_a_DecisionMergeNode() throws XtumlException {
        DecisionMergeNodeSet decisionmergenodeset = new DecisionMergeNodeSetImpl();
        for ( ControlNode controlnode : this ) decisionmergenodeset.add( controlnode.R1106_is_a_DecisionMergeNode() );
        return decisionmergenodeset;
    }
    @Override
    public FlowFinalNodeSet R1106_is_a_FlowFinalNode() throws XtumlException {
        FlowFinalNodeSet flowfinalnodeset = new FlowFinalNodeSetImpl();
        for ( ControlNode controlnode : this ) flowfinalnodeset.add( controlnode.R1106_is_a_FlowFinalNode() );
        return flowfinalnodeset;
    }
    @Override
    public ForkJoinNodeSet R1106_is_a_ForkJoinNode() throws XtumlException {
        ForkJoinNodeSet forkjoinnodeset = new ForkJoinNodeSetImpl();
        for ( ControlNode controlnode : this ) forkjoinnodeset.add( controlnode.R1106_is_a_ForkJoinNode() );
        return forkjoinnodeset;
    }
    @Override
    public InitialNodeSet R1106_is_a_InitialNode() throws XtumlException {
        InitialNodeSet initialnodeset = new InitialNodeSetImpl();
        for ( ControlNode controlnode : this ) initialnodeset.add( controlnode.R1106_is_a_InitialNode() );
        return initialnodeset;
    }


    @Override
    public ControlNode nullElement() {
        return ControlNodeImpl.EMPTY_CONTROLNODE;
    }

    @Override
    public ControlNodeSet emptySet() {
      return new ControlNodeSetImpl();
    }

    @Override
    public ControlNodeSet emptySet(Comparator<? super ControlNode> comp) {
      return new ControlNodeSetImpl(comp);
    }

    @Override
    public ControlNodeSet value() {
        return this;
    }

    @Override
    public List<ControlNode> elements() {
        return Arrays.asList(toArray(new ControlNode[0]));
    }

}
